==> pagedesigner_block_adaptable-2.1.2.tar.gz: pagedesigner_block_adaptable/src/Plugin/pagedesigner_block_adaptable/Filter/Bundle.php <==
<?php

namespace Drupal\pagedesigner_block_adaptable\Plugin\pagedesigner_block_adaptable\Filter;

use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner\Plugin\FieldHandlerBase;
use Drupal\pagedesigner_block_adaptable\Plugin\FilterPluginBase;

/**
 * Process entities of type "bundle".
 *
 * @PagedesignerFilter(
 *   id = "pagedesigner_filter_bundle",
 *   name = @Translation("Bundle filter"),
 *   types = {
 *     "bundle",
 *   },
 * )
 */
class Bundle extends FilterPluginBase {

  /**
   * {@inheritDoc}
   */
  public function build(array $filter) {
    // Workaround for the content type, because there
    // can not be a key named 'type' in the definition.
    if ($filter['field'] === 'type') {
      $bundleFilter = $filter;
      $options = [];
      $values = [];
      foreach ($filter['value'] as $key => $option) {
        if (\Drupal::entityTypeManager()->getStorage('node_type')->load($option) != NULL) {
          $options[$key] = \Drupal::entityTypeManager()->getStorage('node_type')->load($option)->label();
          $values[$key] = TRUE;
        }
      }
      return [
        'description' => 'Choose type',
        'label' => 'Type',
        'options' => $options,
        'type' => 'multiplecheckbox',
        'name' => 'content_type',
        'value' => $values,
      ];
    }
    else {
      $values = [];
      return [
        'description' => 'Choose options',
        'label' => $filter['field'],
        'options' => $filter['value'],
        'type' => 'multiplecheckbox',
        'name' => $filter['field'],
        'value' => $values,
      ];
    }
  }

  /**
   * {@inheritDoc}
   */
  public function patch($value) {
    $result = [];
    foreach ($value as $filter_key => $item) {
      if ($item) {
        $result[$filter_key] = TRUE;
      }
      else {
        $result[$filter_key] = FALSE;
      }
    }
    return $result;
  }

}

==> pagedesigner_block_adaptable-2.3.1.tar.gz: pagedesigner_block_adaptable/src/Plugin/pagedesigner_block_adaptable/Filter/Bundle.php <==
<?php

namespace Drupal\pagedesigner_block_adaptable\Plugin\pagedesigner_block_adaptable\Filter;

use Drupal\pagedesigner_block_adaptable\Plugin\FilterPluginBase;

/**
 * Process entities of type "bundle".
 *
 * @PagedesignerFilter(
 *   id = "pagedesigner_filter_bundle",
 *   name = @Translation("Bundle filter"),
 *   types = {
 *     "bundle",
 *   },
 * )
 */
class Bundle extends FilterPluginBase {

  /**
   * {@inheritDoc}
   */
  public function build(array &$filterDefinition): array {
    // Workaround for the content type, because there
    // can not be a key named 'type' in the definition.
    if ($filterDefinition['field'] === 'type') {
      $options = [];
      $values = [];
      foreach ($filterDefinition['value'] as $key => $option) {
        if (\Drupal::entityTypeManager()->getStorage('node_type')->load($option) != NULL) {
          $options[$key] = \Drupal::entityTypeManager()->getStorage('node_type')->load($option)->label();
          $values[$key] = TRUE;
        }
      }
      return [
        'description' => 'Choose type',
        'label' => 'Type',
        'options' => $options,
        'type' => 'multiplecheckbox',
        'name' => $filterDefinition['id'],
        'value' => $values,
      ];
    }
    else {
      $values = [];
      return [
        'description' => 'Choose options',
        'label' => $filterDefinition['field'],
        'options' => $filterDefinition['value'],
        'type' => 'multiplecheckbox',
        'name' => $filterDefinition['id'],
        'value' => $values,
      ];
    }
  }

  /**
   * {@inheritDoc}
   */
  public function view(array &$filterDefinition, $value) {
    $result = [];
    foreach ($value as $filter_key => $item) {
      if ($item) {
        $result[$filter_key] = $filter_key;
      }
      else {
        unset($result[$filter_key]);
      }
    }
    return $result;
  }

  /**
   * {@inheritDoc}
   */
  public function patchPrepare(array &$filterDefinition, $value) {
    $result = [];
    foreach ($value as $filter_key => $item) {
      if ($item) {
        $result[$filter_key] = $filter_key;
      }
      else {
        unset($result[$filter_key]);
      }
    }
    return $result;
  }

}
